summaryrefslogtreecommitdiff
path: root/ted.h
diff options
context:
space:
mode:
authorpommicket <pommicket@gmail.com>2022-12-29 23:13:23 -0500
committerpommicket <pommicket@gmail.com>2022-12-29 23:13:23 -0500
commita0f8332da674d452f7ae4f84f01d4682d464c9b2 (patch)
treed003832a43f92b8b466815dc3f1354e5b69da11d /ted.h
parentadbfd5f248d390ae73eb9da636a457ce770c9ac0 (diff)
show the wait cursor when waiting for go to definition
Diffstat (limited to 'ted.h')
-rw-r--r--ted.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/ted.h b/ted.h
index be8fcb0..fd2cf9f 100644
--- a/ted.h
+++ b/ted.h
@@ -414,11 +414,13 @@ typedef struct {
} Hover;
typedef struct {
-
- // LSPID and ID of the last response which was processed.
- // used to process responses in chronological order (= ID order)
- LSPID last_response_lsp;
- u32 last_response_id;
+ // LSPID and ID of the last request which was sent out.
+ // used to process responses in chronological order (= ID order).
+ // if we got a response for the last request, or no requests have been made,
+ // last_request_lsp is set to 0.
+ LSPID last_request_lsp;
+ u32 last_request_id;
+ struct timespec last_request_time;
} Definitions;
@@ -488,7 +490,8 @@ typedef struct Ted {
// used by menus to keep track of the scroll position so we can return to it.
v2d prev_active_buffer_scroll;
- SDL_Cursor *cursor_arrow, *cursor_ibeam, *cursor_resize_h, *cursor_resize_v, *cursor_hand, *cursor_move;
+ SDL_Cursor *cursor_arrow, *cursor_ibeam, *cursor_wait,
+ *cursor_resize_h, *cursor_resize_v, *cursor_hand, *cursor_move;
SDL_Cursor *cursor; // which cursor to use this frame (NULL for no cursor)
// node containing tab user is dragging around, NULL if user is not dragging a tab